print(__doc__)

import matplotlib.pyplot as plt

from sklearn.datasets import make_classification
from sklearn.datasets import make_blobs
from sklearn.datasets import make_gaussian_quantiles

import numpy as np
import nibabel as nib
import os.path as op


def read_nii(volume_path):
    nii = nib.load(volume_path)
    data = nii.get_data()
    header = nii.header
    affine = nii.affine
    spacing = list(nii.header['pixdim'][1:4])
    return data, header, affine, spacing


val_path = 'C:\code\data\\train'
img_id = [3, 5, 6, 7, 9, 17, 24, 28, 31, 40, 42, 46, 47, 51, 58, 62, 72, 84, 85, 86, 93, 107, 114, 122, 125]
# images with spacing < 1
img_id_0 = [84, 86, 85, 5, 17, 93, 107, ]  # 114
# images with spacing = 1
img_id_1 = [3, 6, 7, 9, 28, 31, 40, 42, 46, ]  # 47
# images with spacing > 1
img_id_2 = [24, 51, 58, 62, 72, 122, 125]

baseline = [0.7034, 0.083, 0.7873, 0.7934, 0.7823, 0.7574, 0.5053, 0.8452, 0.6402, 0.7902, 0.7005, 0.612, 1, 0.8043,
            0.1324, 0.3086, 0.8121, 0.6523, 0.4723, 0.3556, 0.6951, 0.2315, 1, 0.6251, 0.7136]
md = [0.7457, 0.093, 0.7955, 0.807, 0.8005, 0.7677, 0.5565, 0.8661, 0.6457, 0.7875, 0.7447, 0.6509, 1, 0.7753, 0.1962,
      0.046, 0.8112, 0.6983, 0.6125, 0.5153, 0.7051, 0.2451, 1, 0.7092, 0.7233]
md_sdb = [0.7374, 0.31, 0.8066, 0.8253, 0.7902, 0.7699, 0.5668, 0.8701, 0.6612, 0.7933, 0.7065, 0.5956, 1, 0.8061,
          0.3412, 0.2494, 0.7925, 0.6854, 0.4817, 0.5088, 0.7455, 0.2613, 1, 0.6851, 0.727]
md_dcd = [0.6991, 0.5098, 0.7981, 0.8213, 0.8191, 0.7904, 0.5619, 0.8058, 0.6464, 0.8075, 0.7155, 0.6104, 1, 0.7941,
          0.363, 0.0186, 0.7953, 0.6682, 0.5157, 0.3691, 0.7451, 0.2894, 1, 0.6534, 0.732]
md_sdb_dcd = [0.7992, 0.555, 0.817, 0.8299, 0.828, 0.7759, 0.5695, 0.8529, 0.6949, 0.8108, 0.7539, 0.6209, 1, 0.7892,
              0.4423, 0.3751, 0.8163, 0.6784, 0.5498, 0.5448, 0.7078, 0.307, 1, 0.6592, 0.7189]

img_id_idx = dict()
for idx, id in enumerate(img_id):
    img_id_idx[id] = idx

spacing_dict = dict()
for id in img_id:
    patient = 'volume-' + str(id) + '.nii'
    data, header, affine, spacing = read_nii(op.join(val_path, patient))
    spacing_dict[id] = spacing[-1]

plt.figure(figsize=(13, 5))
plt.subplots_adjust(bottom=.1, top=.935, left=.05, right=.985)

ax1 = plt.subplot(131)
plt.title("Spacing < 1.0", fontsize='small')
p0 = plt.scatter([1], [md[img_id_idx[84]]], marker='o', c='LimeGreen', alpha=0.9, s=25, edgecolor='k', label='Baseline')
p1 = plt.scatter([1], [md[img_id_idx[84]]], marker='o', c='green', alpha=0.9, s=25, edgecolor='k', label='MD')
p2 = plt.scatter([1], [md_sdb[img_id_idx[84]]], marker='o', c='MidnightBlue', alpha=0.9, s=25, edgecolor='k',
                 label='MD+SDB')
p3 = plt.scatter([1], [md_dcd[img_id_idx[84]]], marker='o', c='purple', alpha=0.9, s=25, edgecolor='k', label='MD+DCD')
p4 = plt.scatter([1], [md_sdb_dcd[img_id_idx[84]]], marker='o', c='Gold', alpha=0.9, s=25, edgecolor='k',
                 label='MD+SDB+DCD')
plt.legend(loc='lower left', fontsize='small')
X1, Y1, S, C = [], [], [], []
for idx, id in enumerate(img_id_0):
    X1 += [idx + 1] * 5
    Y1 += [baseline[img_id_idx[id]], md[img_id_idx[id]], md_sdb[img_id_idx[id]], md_dcd[img_id_idx[id]],
           md_sdb_dcd[img_id_idx[id]]]
    S += [spacing_dict[id] * 200] * 5
    C += ['LimeGreen', 'green', 'MidnightBlue', 'purple', 'Gold']  # [0, 1, 2, 3]
plt.scatter(X1, Y1, marker='o', c=C, alpha=1., s=S, edgecolor='k')
plt.xlabel('ID')
plt.ylabel('Dice')

plt.subplot(132)
plt.title("Spacing = 1.0", fontsize='small')
p0 = plt.scatter([1], [md[img_id_idx[3]]], marker='o', c='LimeGreen', alpha=0.9, s=25, edgecolor='k', label='Baseline')
p1 = plt.scatter([1], [md[img_id_idx[3]]], marker='o', c='green', alpha=0.9, s=25, edgecolor='k', label='MD')
p2 = plt.scatter([1], [md_sdb[img_id_idx[3]]], marker='o', c='MediumBlue', alpha=0.9, s=25, edgecolor='k',
                 label='MD+SDB')
p3 = plt.scatter([1], [md_dcd[img_id_idx[3]]], marker='o', c='purple', alpha=0.9, s=25, edgecolor='k', label='MD+DCD')
p4 = plt.scatter([1], [md_sdb_dcd[img_id_idx[3]]], marker='o', c='Gold', alpha=0.9, s=25, edgecolor='k',
                 label='MD+SDB+DCD')
plt.legend(loc='lower left', fontsize='small')
X1, Y1, S, C = [], [], [], []
for idx, id in enumerate(img_id_1):
    X1 += [idx + 1] * 5
    Y1 += [baseline[img_id_idx[id]], md[img_id_idx[id]], md_sdb[img_id_idx[id]], md_dcd[img_id_idx[id]],
           md_sdb_dcd[img_id_idx[id]]]
    S += [spacing_dict[id] * 200] * 5
    C += ['LimeGreen', 'green', 'MidnightBlue', 'purple', 'Gold']  # [0, 1, 2, 3]
plt.scatter(X1, Y1, marker='o', c=C, alpha=1., s=S, edgecolor='k')
plt.xlabel('ID')
plt.ylabel('Dice')
my_x_ticks = np.arange(0, 11, 2)
plt.xticks(my_x_ticks)

plt.subplot(133)
plt.title("Spacing > 1.0", fontsize='small')
p0 = plt.scatter([1], [md[img_id_idx[24]]], marker='o', c='LimeGreen', alpha=0.9, s=25, edgecolor='k', label='Baseline')
p1 = plt.scatter([1], [md[img_id_idx[24]]], marker='o', c='green', alpha=0.9, s=25, edgecolor='k', label='MD')
p2 = plt.scatter([1], [md_sdb[img_id_idx[24]]], marker='o', c='MediumBlue', alpha=0.9, s=25, edgecolor='k',
                 label='MD+SDB')
p3 = plt.scatter([1], [md_dcd[img_id_idx[24]]], marker='o', c='purple', alpha=0.9, s=25, edgecolor='k', label='MD+DCD')
p4 = plt.scatter([1], [md_sdb_dcd[img_id_idx[24]]], marker='o', c='Gold', alpha=0.9, s=25, edgecolor='k',
                 label='MD+SDB+DCD')
plt.legend(loc='lower right', fontsize='small')
X1, Y1, Y2, Y3, Y4, S, C = [], [], [], [], [], [], []
for idx, id in enumerate(img_id_2):
    X1 += [idx + 1] * 5
    Y1 += [baseline[img_id_idx[id]], md[img_id_idx[id]], md_sdb[img_id_idx[id]], md_dcd[img_id_idx[id]],
           md_sdb_dcd[img_id_idx[id]]]
    S += [spacing_dict[id] * 200] * 5
    C += ['LimeGreen', 'green', 'MidnightBlue', 'purple', 'Gold']  # [0, 1, 2, 3]
plt.scatter(X1, Y1, marker='o', c=C, alpha=1., s=S, edgecolor='k')
plt.xlabel('ID')
plt.ylabel('Dice')

# plt.legend([p1, p4], ['label', 'label1'], loc='lower right', scatterpoints=1)


plt.show()
